===========
Change Log
===========

**Managing DMARC aggregate and feedback reports**

Designed to quickly and easily manage DMARC aggregate and feedback reports.

Change Log
==========

.. include:: ../CHANGELOG

Copyright
=========

Django DMARC and this documentation is
Copyright (c) 2015-2019, Persistent Objects Ltd.
All rights reserved.

License
=======

This documentation is licensed under the Creative Commons Attribution 4.0
International License. To view a copy of this license, visit
http://creativecommons.org/licenses/by/4.0/.

.. include:: ../LICENSE
